@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Type::Params qw/compile_named_oo compile/;
 use Types::Standard qw/CodeRef/;
@@ -20,10 +20,11 @@ sub cpo {
 		$compile{$key} = CodeRef;
 		ref $params{$key} eq 'HASH' ? do {
 			my @b;
-			push @b, ref $params{$key}{$_} eq 'HASH' 
-				? ( $_ => delete $params{$key}{$_}{type} => $params{$key}{$_} )
-				: ($_ => $params{$key}{$_})
-			for keys %{$params{$key}};
+			ref $params{$key}{$_} eq 'HASH' ? do {
+				push @b, $_ => delete $params{$key}{$_}{type} => $params{$key}{$_};
+			} : do {
+				push @b, $_ => $params{$key}{$_};
+			} for keys %{$params{$key}};
 			$build{$key} = compile_named_oo(@b);
 		} : do {
 			$build{$key} = compile(@{$params{$key}});
@@ -44,7 +45,7 @@ Compiled::Params::OO - compiled params object oriented.
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
@@ -68,11 +69,11 @@ Version 0.02
 			circles => [Str, Int]
 		);
 	}
-
+	 
 	sub new {
 		return bless {}, $_[0];
 	}
-
+	 
 	sub time {
 		my $self = shift;
 		my $params = $validate->time->(
@@ -80,13 +81,15 @@ Version 0.02
 		);
 		return $params->me;
 	}
-
+	 
 	sub circles {
 		my $self = shift;
 		my @params = $validate->circles->('dreaming', 211000000);
 		return \@params;
 	}
 
+	1;
+
 =head1 EXPORT
 
 =head2 cpo
@@ -100,10 +103,10 @@ a type and default value.
 
 	$validate = cpo(
 		time => {
-			testing => Int
+			testing => Int,
 			me => {
 				type => Str,
-				default => {
+				default => sub {
 					return 'house of lords';
 				}
 			}
@@ -113,6 +116,34 @@ a type and default value.
 
 =cut
 
+=head1 Examples
+
+=cut
+
+=head2 Optional params
+
+The following example demonstrates how to validate optional parameters.
+
+	my $validate = cpo(
+		new_pdf => {
+			name => Optional->of(Str),
+			page_size => {
+				type => Optional->of(Enum[qw/A1 A2 A3 A4 A5/]), 
+				default => sub { 'A4' },
+			},
+			pages => Optional->of(ArrayRef),
+			num => {
+				type => Optional->of(Int), 
+				default => sub { 0 } 
+			},
+			page_args => Optional->of(HashRef), 
+			plugins => Optional->of(ArrayRef) 
+		},
+		end_pdf => [Str, Optional->of(Int)]
+	);
+
+=cut
+
 =head1 AUTHOR
 
 lnation, C<< <email at lnation.org> >>
